==> neptune_ui-1.0.0.219.jar: com/tandbergtv/neptune/ui/realm/client/tab/user/UiUser.java <==
package com.tandbergtv.neptune.ui.realm.client.tab.user;

import java.util.Date;
import java.util.HashSet;
import java.util.Set;

import com.google.gwt.user.client.rpc.IsSerializable;
import com.tandbergtv.neptune.ui.realm.client.tab.role.UiRoleKey;

public class UiUser implements IsSerializable {
	private UiUserKey key = new UiUserKey();
	private String userName;
	private String password;
	private boolean active = true;
	private String firstName;
	private String lastName;
	private String email;
	private String phone;
	private String extension;
	private String employeeId;
	private String department;
	private String location;
	private Date passwordModifiedDate;
	private Set<UiRoleKey> roleIds = new HashSet<UiRoleKey>();
	private boolean changePassword = false;

	public UiUser() {
	}

	public Long getId() {
		return this.key.getId();
	}

	public void setId(Long id) {
		this.key.setId(id);
	}

	public String getExternalKey() {
		return this.key.getExternalKey();
	}
	
	public void setExternalKey(String externalKey) {
		this.key.setExternalKey(externalKey);
	}
	
	public UiUserKey getKey() {
		return key;
	}

	public void setKey(UiUserKey key) {
		if (key == null)
			key = new UiUserKey();

		this.key = key;
	}

	public String getUserName() {
		return userName;
	}

	public void setUserName(String userName) {
		this.userName = userName;
	}

	public String getPassword() {
		return password;
	}

	public void setPassword(String password) {
		this.password = password;
	}

	public boolean isActive() {
		return active;
	}

	public void setActive(boolean active) {
		this.active = active;
	}

	public String getFirstName() {
		return firstName;
	}

	public void setFirstName(String firstName) {
		this.firstName = firstName;
	}

	public String getLastName() {
		return lastName;
	}

	public void setLastName(String lastName) {
		this.lastName = lastName;
	}

	public String getEmail() {
		return email;
	}

	public void setEmail(String email) {
		this.email = email;
	}

	public String getPhone() {
		return phone;
	}

	public void setPhone(String phone) {
		this.phone = phone;
	}

	public String getExtension() {
		return extension;
	}

	public void setExtension(String extension) {
		this.extension = extension;
	}

	public String getEmployeeId() {
		return employeeId;
	}

	public void setEmployeeId(String employeeId) {
		this.employeeId = employeeId;
	}

	public String getDepartment() {
		return department;
	}

	public void setDepartment(String department) {
		this.department = department;
	}

	public String getLocation() {
		return location;
	}

	public void setLocation(String location) {
		this.location = location;
	}

	public Set<UiRoleKey> getRoleIds() {
		return roleIds;
	}

	public void setRoleIds(Set<UiRoleKey> roleIds) {
		this.roleIds = roleIds;
	}

	public Date getPasswordModifiedDate() {
		return passwordModifiedDate;
	}

	public void setPasswordModifiedDate(Date passwordModifiedDate) {
		this.passwordModifiedDate = passwordModifiedDate;
	}

	/**
	 * @return the changePassword
	 */
	public boolean isChangePassword() {
		return changePassword;
	}

	/**
	 * @param changePassword the changePassword to set
	 */
	public void setChangePassword(boolean changePassword) {
		this.changePassword = changePassword;
	}

	/*
     * @see java.lang.Object#hashCode()
     */
    @Override
    public int hashCode() {
	    return key.hashCode() + 31;
    }

	/* (non-Javadoc)
     * @see java.lang.Object#equals(java.lang.Object)
     */
    @Override
    public boolean equals(Object obj) {
	    if (!(obj instanceof UiUser))
		    return false;
	    UiUser other = (UiUser) obj;
	    return key.equals(other.key);
    }
}

==> neptune_ui-1.0.0.249.jar: com/tandbergtv/neptune/ui/realm/client/tab/user/UiUser.java <==
package com.tandbergtv.neptune.ui.realm.client.tab.user;

import java.util.Date;
import java.util.HashSet;
import java.util.Set;

import com.google.gwt.user.client.rpc.IsSerializable;
import com.tandbergtv.neptune.ui.realm.client.tab.role.UiRoleKey;

public class UiUser implements IsSerializable {
	private UiUserKey key = new UiUserKey();
	private String userName;
	private String password;
	private boolean active = true;
	private String firstName;
	private String lastName;
	private String email;
	private String phone;
	private String extension;
	private String employeeId;
	private String department;
	private String location;
	private Date passwordModifiedDate;
	private Set<UiRoleKey> roleIds = new HashSet<UiRoleKey>();
	private boolean changePassword = false;
	private boolean readOnly;

	public UiUser() {
	}

	public Long getId() {
		return this.key.getId();
	}

	public void setId(Long id) {
		this.key.setId(id);
	}

	public String getExternalKey() {
		return this.key.getExternalKey();
	}

	public void setExternalKey(String externalKey) {
		this.key.setExternalKey(externalKey);
	}

	public UiUserKey getKey() {
		return key;
	}

	public void setKey(UiUserKey key) {
		if (key == null)
			key = new UiUserKey();

		this.key = key;
	}

	public String getUserName() {
		return userName;
	}

	public void setUserName(String userName) {
		this.userName = userName;
	}

	public String getPassword() {
		return password;
	}

	public void setPassword(String password) {
		this.password = password;
	}

	public boolean isActive() {
		return active;
	}

	public void setActive(boolean active) {
		this.active = active;
	}

	public String getFirstName() {
		return firstName;
	}

	public void setFirstName(String firstName) {
		this.firstName = firstName;
	}

	public String getLastName() {
		return lastName;
	}

	public void setLastName(String lastName) {
		this.lastName = lastName;
	}

	public String getEmail() {
		return email;
	}

	public void setEmail(String email) {
		this.email = email;
	}

	public String getPhone() {
		return phone;
	}

	public void setPhone(String phone) {
		this.phone = phone;
	}

	public String getExtension() {
		return extension;
	}

	public void setExtension(String extension) {
		this.extension = extension;
	}

	public String getEmployeeId() {
		return employeeId;
	}

	public void setEmployeeId(String employeeId) {
		this.employeeId = employeeId;
	}

	public String getDepartment() {
		return department;
	}

	public void setDepartment(String department) {
		this.department = department;
	}

	public String getLocation() {
		return location;
	}

	public void setLocation(String location) {
		this.location = location;
	}

	public Set<UiRoleKey> getRoleIds() {
		return roleIds;
	}

	public void setRoleIds(Set<UiRoleKey> roleIds) {
		this.roleIds = roleIds;
	}

	public Date getPasswordModifiedDate() {
		return passwordModifiedDate;
	}

	public void setPasswordModifiedDate(Date passwordModifiedDate) {
		this.passwordModifiedDate = passwordModifiedDate;
	}

	/**
	 * @return the changePassword
	 */
	public boolean isChangePassword() {
		return changePassword;
	}

	/**
	 * @param changePassword the changePassword to set
	 */
	public void setChangePassword(boolean changePassword) {
		this.changePassword = changePassword;
	}

	/**
	 * @return the readOnly
	 */
	public boolean isReadOnly() {
		return readOnly;
	}

	/**
	 * @param readOnly the readOnly to set
	 */
	public void setReadOnly(boolean readOnly) {
		this.readOnly = readOnly;
	}

	/*
	 * @see java.lang.Object#hashCode()
	 */
	@Override
	public int hashCode() {
		return key.hashCode() + 31;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see java.lang.Object#equals(java.lang.Object)
	 */
	@Override
	public boolean equals(Object obj) {
		if (!(obj instanceof UiUser))
			return false;
		UiUser other = (UiUser) obj;
		return key.equals(other.key);
	}
}
